# Generated by roxygen2: do not edit by hand

export(calculate_pip_threshold)
export(calculate_stats_gamma)
export(calculate_stats_gaussian)
export(estimate_mv_moments)
export(estimate_mv_shape_rate)
export(generate_mvGamma_data)
export(simulate_group_data)
export(simulate_group_gamma)
export(simulate_group_gaussian)
export(trans_log)
export(trans_ratio)
export(trans_root)
importFrom(MASS,mvrnorm)
importFrom(stats,cor)
importFrom(stats,mad)
importFrom(stats,pnorm)
importFrom(stats,qgamma)
importFrom(stats,sd)
